<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ro_RO">
<context>
    <name>LXQtQuickLaunch</name>
    <message>
        <location filename="../lxqtquicklaunch.cpp" line="229"/>
        <source>Drop Error</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lxqtquicklaunch.cpp" line="230"/>
        <source>File/URL &apos;%1&apos; cannot be embedded into QuickLaunch for now</source>
        <translation>Fișierul/URL-ul &apos;%1&apos; nu poate fi inclus în lista de lansare rapidă momentan</translation>
    </message>
    <message>
        <location filename="../lxqtquicklaunch.cpp" line="336"/>
        <source>Drop application
icons here</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QuickLaunchButton</name>
    <message>
        <location filename="../quicklaunchbutton.cpp" line="55"/>
        <source>(Ctrl + DND)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../quicklaunchbutton.cpp" line="57"/>
        <source>Move left</source>
        <translation>Mută spre stânga</translation>
    </message>
    <message>
        <location filename="../quicklaunchbutton.cpp" line="60"/>
        <source>Move right</source>
        <translation>Mută spre dreapta</translation>
    </message>
    <message>
        <location filename="../quicklaunchbutton.cpp" line="63"/>
        <source>Remove from quicklaunch</source>
        <translation>Îndepărtează din lista pentru lansare rapidă</translation>
    </message>
    <message>
        <location filename="../quicklaunchbutton.cpp" line="72"/>
        <source>Refresh</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
